<?php
/**
* The template for adding color options in Customizer
*
* @package Catch Themes
* @subpackage Rock Star Pro
* @since Rock Star 1.0
*/

$wp_customize->add_panel( 'rock_star_color_options', array(
	'capability'  => 'edit_theme_options',
	'description' => esc_html__( 'Color Options', 'rock-star-pro' ),
	'priority'    => 300,
	'title'       => esc_html__( 'Color Options', 'rock-star-pro' ),
) );

//Basic Color Options
$wp_customize->add_section( 'rock_star_color_scheme', array(
	'panel' => 'rock_star_color_options',
	'title' => esc_html__( 'Basic Color Options', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[color_scheme]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['color_scheme'],
	'sanitize_callback' => 'rock_star_sanitize_select',
) );

$wp_customize->add_control( 'rock_star_theme_options[color_scheme]', array(
	'label'    => esc_html__( 'Color Scheme', 'rock-star-pro' ),
	'priority' => 1,
	'section'  => 'rock_star_color_scheme',
	'settings' => 'rock_star_theme_options[color_scheme]',
	'type'     => 'radio',
	'choices'  => rock_star_color_scheme_options(),
	'default'  => $defaults['color_scheme'],
) );

$basic_colors	=	rock_star_get_basic_color_options();

foreach ( $basic_colors as $key => $color_option ) {
	$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults[ $key ],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'rock_star_theme_options['. $key .']', array(
		'label'    => $color_option,
		'section'  => 'rock_star_color_scheme',
		'settings' => 'rock_star_theme_options['. $key .']',
	) ) );
}



//Menu Color Options
$wp_customize->add_section( 'rock_star_primary_menu_color_options', array(
	'panel' => 'rock_star_color_options',
	'title' => esc_html__( 'Primary Menu Color Options', 'rock-star-pro' ),
) );

$menu_color_options	= rock_star_get_menu_color_options();

foreach ( $menu_color_options as $key => $color_option ) {
	$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults[ $key ],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'rock_star_theme_options['. $key .']', array(
		'label'    => $color_option,
		'section'  => 'rock_star_primary_menu_color_options',
		'settings' => 'rock_star_theme_options['. $key .']',
	) ) );
}

$wp_customize->add_section( 'rock_star_secondary_menu_color_options', array(
	'panel' => 'rock_star_color_options',
	'title' => esc_html__( 'Secondary Menu Color Options', 'rock-star-pro' ),
) );

//Header Color Option
$wp_customize->add_section( 'rock_star_header_color_options', array(
	'panel' => 'rock_star_color_options',
	'title' => esc_html__( 'Header Color Options', 'rock-star-pro' ),
) );

$header_colors	=	rock_star_get_header_color_options();

foreach ( $header_colors as $key => $color_option ) {
	$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults[ $key ],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'rock_star_theme_options['. $key .']', array(
		'label'    => $color_option,
		'section'  => 'rock_star_header_color_options',
		'settings' => 'rock_star_theme_options['. $key .']',
	) ) );
}

//Slider Color Option
$wp_customize->add_section( 'rock_star_slider_color_options', array(
	'panel' => 'rock_star_color_options',
	'title' => esc_html__( 'Slider Color Options', 'rock-star-pro' ),
) );

$slider_options	=	rock_star_get_slider_color_options();

foreach ( $slider_options as $key => $color_option ) {
	$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults[ $key ],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'rock_star_theme_options['. $key .']', array(
		'label'    => $color_option,
		'section'  => 'rock_star_slider_color_options',
		'settings' => 'rock_star_theme_options['. $key .']',
	) ) );
}

//News Ticker Color Options
$wp_customize->add_section( 'rock_star_news_ticker_color_options', array(
	'panel' => 'rock_star_color_options',
	'title' => esc_html__( 'News Ticker Color Options', 'rock-star-pro' ),
) );

$news_ticker_options	=	rock_star_get_news_ticker_color_options();

foreach ( $news_ticker_options as $key => $color_option ) {
	$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults[ $key ],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'rock_star_theme_options['. $key .']', array(
		'label'    => $color_option,
		'section'  => 'rock_star_news_ticker_color_options',
		'settings' => 'rock_star_theme_options['. $key .']',
	) ) );
}

//Featured Content Color Options
$wp_customize->add_section( 'rock_star_featured_content_color_options', array(
	'panel' => 'rock_star_color_options',
	'title' => esc_html__( 'Featured Content Color Options', 'rock-star-pro' ),
) );

$featured_content_options	=	rock_star_get_featured_content_color_options();

foreach ( $featured_content_options as $key => $color_option ) {
	$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults[ $key ],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'rock_star_theme_options['. $key .']', array(
		'label'    => $color_option,
		'section'  => 'rock_star_featured_content_color_options',
		'settings' => 'rock_star_theme_options['. $key .']',
	) ) );
}

//Content Color Option
$wp_customize->add_section( 'rock_star_content_color_options', array(
	'panel' => 'rock_star_color_options',
	'title' => esc_html__( 'Content Color Options', 'rock-star-pro' ),
) );

$content_color_options	=	rock_star_get_content_color_options();

foreach ( $content_color_options as $key => $color_option ) {
	$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults[ $key ],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'rock_star_theme_options['. $key .']', array(
		'label'    => $color_option,
		'section'  => 'rock_star_content_color_options',
		'settings' => 'rock_star_theme_options['. $key .']',
	) ) );
}

//Sidebar Color Option
$wp_customize->add_section( 'rock_star_sidebar_color_options', array(
	'description' => esc_html__( 'Only for Primary Sidebar', 'rock-star-pro' ),
	'panel'       => 'rock_star_color_options',
	'title'       => esc_html__( 'Sidebar Color Options', 'rock-star-pro' ),
) );

$sidebar_color_options	=	rock_star_get_sidebar_color_options();

foreach ( $sidebar_color_options as $key => $color_option ) {
	$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults[ $key ],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'rock_star_theme_options['. $key .']', array(
		'label'    => $color_option,
		'section'  => 'rock_star_sidebar_color_options',
		'settings' => 'rock_star_theme_options['. $key .']',
	) ) );
}

//Pagination Color Option
$wp_customize->add_section( 'rock_star_pagination_color_options', array(
	'panel' => 'rock_star_color_options',
	'title' => esc_html__( 'Pagination Color Options', 'rock-star-pro' ),
) );

$pagination_color_options = rock_star_get_pagination_color_options();

foreach ( $pagination_color_options as $key => $color_option ) {
	$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults[ $key ],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'rock_star_theme_options['. $key .']', array(
		'label'    => $color_option,
		'section'  => 'rock_star_pagination_color_options',
		'settings' => 'rock_star_theme_options['. $key .']',
	) ) );
}

//Footer Color Option
$wp_customize->add_section( 'rock_star_footer_color_options', array(
	'panel' => 'rock_star_color_options',
	'title' => esc_html__( 'Footer Color Options', 'rock-star-pro' ),
) );

$footer_color_options	=	rock_star_get_footer_color_options();

foreach ( $footer_color_options as $key => $color_option ) {
	$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults[ $key ],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'rock_star_theme_options['. $key .']', array(
		'label'    => $color_option,
		'section'  => 'rock_star_footer_color_options',
		'settings' => 'rock_star_theme_options['. $key .']',
	) ) );
}

//Scrollup Color Option
$wp_customize->add_section( 'rock_star_scrollup_color_options', array(
	'panel' => 'rock_star_color_options',
	'title' => esc_html__( 'Scrollup Color Options', 'rock-star-pro' ),
) );

$scrollup_options	=	rock_star_get_scrollup_color_options();

foreach ( $scrollup_options as $key => $color_option ) {
	$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults[ $key ],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'rock_star_theme_options['. $key .']', array(
		'label'    => $color_option,
		'section'  => 'rock_star_scrollup_color_options',
		'settings' => 'rock_star_theme_options['. $key .']',
	) ) );
}