<?php
/**
* The template for Social Links in Customizer
*
* @package Catch Themes
* @subpackage Rock Star Pro
* @since Rock Star 1.0
*/

$wp_customize->add_panel( 'rock_star_social_links', array(
    'capability'     => 'edit_theme_options',
    'description'	=> esc_html__( 'Note: Enter the url for correponding social networking website', 'rock-star-pro' ),
    'priority'       => 700,
	'title'    		 => esc_html__( 'Social Links', 'rock-star-pro' ),
) );

$wp_customize->add_section( 'rock_star_social_links', array(
	'panel'			=> 'rock_star_social_links',
	'priority' 		=> 1,
	'title'   	 	=> esc_html__( 'Social Links', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[social_icon_size]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['social_icon_size'],
	'sanitize_callback'	=> 'absint',
) );

$wp_customize->add_control( 'rock_star_theme_options[social_icon_size]', array(
	'input_attrs' => array(
        'min'   => 10,
        'max'   => 200,
        'step'  => 5,
        'style' => 'width: 60px;'
        ),
	'label'    	=> esc_html__( 'Social Icon Size(px)', 'rock-star-pro' ),
	'priority'	=> '1.5',
	'section' 	=> 'rock_star_social_links',
	'settings'	=> 'rock_star_theme_options[social_icon_size]',
	'type'	   => 'number',
	)
);

$social_icons 	=	rock_star_get_social_icons_list();

foreach ( $social_icons as $key => $value ){
	if ( 'skype_link' == $key ){
		$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback' => 'esc_attr',
			) );

		$wp_customize->add_control( 'rock_star_theme_options['. $key .']', array(
			'description'	=> esc_html__( 'Skype link can be of formats:<br>callto://+{number}<br> skype:{username}?{action}. More Information in readme file', 'rock-star-pro' ),
			'label'    		=> $value['label'],
			'section'  		=> 'rock_star_social_links',
			'settings' 		=> 'rock_star_theme_options['. $key .']',
			'type'	   		=> 'url',
		) );
	}
	else {
		if ( 'email_link' == $key ){
			$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'sanitize_email',
				) );
		}
		elseif ( 'handset_link' == $key || 'phone_link' == $key ){
			$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'sanitize_text_field',
				) );
		}
		else {
			$wp_customize->add_setting( 'rock_star_theme_options['. $key .']', array(
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'esc_url_raw',
				) );
		}

		$wp_customize->add_control( 'rock_star_theme_options['. $key .']', array(
			'label'    => $value['label'],
			'section'  => 'rock_star_social_links',
			'settings' => 'rock_star_theme_options['. $key .']',
			'type'	   => 'url',
		) );
	}
}

$wp_customize->add_section( 'rock_star_custom_social_links', array(
	'description'	=> esc_html__( 'Save and refresh the page if No. of custom social icon is changed (Max number of icons is 10)', 'rock-star-pro' ),
	'panel'			=> 'rock_star_social_links',
	'priority' 		=> 2,
	'title'   	 	=> esc_html__( 'Custom Social Links', 'rock-star-pro' ),
) );

$wp_customize->add_setting( 'rock_star_theme_options[custom_social_icons]', array(
	'capability'		=> 'edit_theme_options',
	'default' 			=> $defaults['custom_social_icons'],
	'sanitize_callback'	=> 'rock_star_sanitize_number_range',
	)
);

$wp_customize->add_control( 'custom_social_icons', array(
	'input_attrs' => array(
        'min'   => 0,
        'max'   => 10,
        'step'  => 1,
        'style' => 'width: 45px;'
        ),
	'label'    	=> esc_html__( 'Number of Custom Social Icons', 'rock-star-pro' ),
	'priority'	=> '1.5',
	'section' 	=> 'rock_star_custom_social_links',
	'settings'	=> 'rock_star_theme_options[custom_social_icons]',
	'type'		=> 'number'
	)
);

$priority	=	6;
//loop for custom social icons
for( $i = 1; $i <= $options['custom_social_icons'] ; $i++ ){
	if ( $i > 9 ) // use this condition to make sure 10 comes after 9 priority wise
		$priority++;

	$wp_customize->add_setting( 'rock_star_theme_options[custom_social_icon_note_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new rock_star_note_control( $wp_customize, 'custom_social_icon_note_'. $i, array(
        'label'		=> esc_html__( 'Custom Social Icon #', 'rock-star-pro' ) . $i,
		'priority'	=> $priority . '.' . $i,
        'section'  	=> 'rock_star_custom_social_links',
        'settings'	=> 'rock_star_theme_options[custom_social_icon_note_'. $i .']',
        'type'     	=> 'description',
		) ) );

		$wp_customize->add_setting( 'rock_star_theme_options[custom_social_icon_title_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'rock_star_theme_options[custom_social_icon_title_'. $i .']', array(
		'label'		=> esc_html__( 'Title', 'rock-star-pro' ),
		'priority'	=> $priority . '.' .$i .$i,
		'section'   => 'rock_star_custom_social_links',
		'settings'  => 'rock_star_theme_options[custom_social_icon_title_'. $i .']',
	) );

	$wp_customize->add_setting( 'rock_star_theme_options[custom_social_icon_image_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'rock_star_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'custom_social_icon_image_'. $i , array(
		'label'		=> esc_html__( 'Image', 'rock-star-pro' ),
        'priority'	=> $priority . '.' . $i .$i .$i,
		'section'   => 'rock_star_custom_social_links',
        'settings'  => 'rock_star_theme_options[custom_social_icon_image_'. $i .']',
	) ) );

		$wp_customize->add_setting( 'rock_star_theme_options[custom_social_icon_image_hover_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'rock_star_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'custom_social_icon_image_hover_'. $i , array(
		'label'		=> esc_html__( 'Hover Image(Optional)', 'rock-star-pro' ),
        'priority'	=> $priority . '.' . $i .$i . $i  .$i,
		'section'   => 'rock_star_custom_social_links',
        'settings'  => 'rock_star_theme_options[custom_social_icon_image_hover_'. $i .']',
	) ) );

	$wp_customize->add_setting( 'rock_star_theme_options[custom_social_icon_link_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'rock_star_theme_options[custom_social_icon_link_'. $i .']', array(
		'label'		=> esc_html__( 'Link', 'rock-star-pro' ),
        'priority'	=> $priority . '.' .$i . $i  . $i  .$i .$i,
		'section'   => 'rock_star_custom_social_links',
        'settings'  => 'rock_star_theme_options[custom_social_icon_link_'. $i .']',
	) );
}