<?php
/**
 * The template for adding Custom Sidebars and Widgets
 *
 * @package Catch Themes
 * @subpackage Rock Star Pro
 * @since Rock Star 1.0
 */

/**
 * Register widgetized area
 *
 * @since Rock Star 1.0
 */
function rock_star_widgets_init() {
    //Primary Sidebar
    register_sidebar( array(
        'name'          => esc_html__( 'Primary Sidebar', 'rock-star-pro' ),
        'id'            => 'primary-sidebar',
        'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
        'after_widget'  => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
        'description'    => esc_html__( 'This is the primary sidebar if you are using a two column site layout option.', 'rock-star-pro' ),
    ) );

    //Footer Widget
    $footer_sidebar_no = 4; //Number of footer sidebars

    for( $i=1; $i <= $footer_sidebar_no; $i++ ) {
        register_sidebar( array(
            'name'          => sprintf( __( 'Footer Area %d', 'rock-star-pro' ), $i ),
            'id'            => sprintf( 'footer-%d', $i ),
            'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
            'after_widget'  => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
            'before_title'  => '<h2 class="widget-title">',
            'after_title'   => '</h2>',
            'description'    => sprintf( __( 'Footer %d widget area.', 'rock-star-pro' ), $i ),
        ) );
    }

    //Featured Widget Content
    register_sidebar( array(
        'name'          => esc_html__( 'Featured Widget Content', 'rock-star-pro' ),
        'id'            => 'featured-widget-content',
        'before_widget' => '<section id="%1$s" class="hentry widget %2$s"><div class="widget-wrap">',
        'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
        'before_title'  => '<h2 class="entry-title">',
        'after_title'   => '</h2>',
        'description'    => esc_html__( 'This is the Featured Widget Content. Enable it by going to Appearance => Customize => Featured Widget Content Options => Enable Featured content Widget Content on', 'rock-star-pro' ),
    ) );


    //Sidebar Before Content
    register_sidebar( array(
        'name'          => esc_html__( 'Before Content', 'rock-star-pro' ),
        'id'            => 'before-content',
        'before_widget' => '<section id="%1$s" class="widget page-section %2$s"><div class="widget-wrap wrapper">',
        'after_widget'  => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
        'description'    => esc_html__( 'This is the Before Content widget area. It typically appears on the before the Content.', 'rock-star-pro' ),
    ) );

    //Sidebar After Content
    register_sidebar( array(
        'name'          => esc_html__( 'After Content', 'rock-star-pro' ),
        'id'            => 'after-content',
        'before_widget' => '<section id="%1$s" class="widget page-section %2$s"><div class="widget-wrap wrapper">',
        'after_widget'  => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
        'description'    => esc_html__( 'This is the After Content widget area. It typically appears after the Content.', 'rock-star-pro' ),
    ) );

    //Sidebar Before Posts/Pages
    register_sidebar( array(
        'name'          => esc_html__( 'Before Posts/Pages', 'rock-star-pro' ),
        'id'            => 'before-posts-pages',
        'before_widget' => '<section id="%1$s" class="widget page-section %2$s"><div class="widget-wrap wrapper">',
        'after_widget'  => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
        'description'    => esc_html__( 'This is the Before Posts/Page widget area. It typically appears on the before Post/Page Content of the site title or logo.', 'rock-star-pro' ),
    ) );

    //Sidebar After Posts/Pages
    register_sidebar( array(
        'name'          => esc_html__( 'After Posts/Pages', 'rock-star-pro' ),
        'id'            => 'after-posts-pages',
        'before_widget' => '<section id="%1$s" class="widget page-section %2$s"><div class="widget-wrap wrapper">',
        'after_widget'  => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
        'description'    => esc_html__( 'This is the After Posts/Page widget area. It typically appears after Post/Page Content.', 'rock-star-pro' ),
    ) );

    // Registering 404 Error Page Content
    register_sidebar( array(
        'name'                    => esc_html__( '404 Page Not Found Content', 'rock-star-pro' ),
        'id'                     => 'sidebar-notfound',
        'description'            => esc_html__( 'Replaces the default 404 Page Not Found Content', 'rock-star-pro' ),
        'before_widget'            => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap wrapper">',
        'after_widget'            => '</div><!-- .widget-wrap --></section>',
        'before_title'            => '<h2 class="widget-title">',
        'after_title'            => '</h2>',
    ) );

    if ( class_exists( 'WooCommerce' ) ) {
        //Optional Primary Sidebar for Shop
        register_sidebar( array(
            'name'                 => esc_html__( 'WooCommerce Primary Sidebar', 'rock-star-pro' ),
            'id'                 => 'sidebar-optional-woocommmerce',
            'description'        => esc_html__( 'This is Optional Primary Sidebar for WooCommerce', 'rock-star-pro' ),
            'before_widget'     => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap wrapper">',
            'after_widget'         => '</div><!-- .widget-wrap --></section>',
            'before_title'         => '<h2 class="widget-title">',
            'after_title'         => '</h2>'
        ) );
    }

    //Optional Sidebar for Hompeage instead of main sidebar
    register_sidebar( array(
        'name'                 => esc_html__( 'Optional Homepage Sidebar', 'rock-star-pro' ),
        'id'                 => 'sidebar-optional-homepage',
        'description'        => esc_html__( 'This is Optional Sidebar for Homepage', 'rock-star-pro' ),
        'before_widget'     => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
        'after_widget'      => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
        'before_title'      => '<h2 class="widget-title">',
        'after_title'       => '</h2>',
    ) );

    //Optional Sidebar for Archive instead of main sidebar
    register_sidebar( array(
        'name'                 => esc_html__( 'Optional Archive Sidebar', 'rock-star-pro' ),
        'id'                 => 'sidebar-optional-archive',
        'description'        => esc_html__( 'This is Optional Sidebar for Archive', 'rock-star-pro' ),
        'before_widget'     => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
        'after_widget'      => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
        'before_title'      => '<h2 class="widget-title">',
        'after_title'       => '</h2>',
    ) );

    //Optional Sidebar for Page instead of main sidebar
    register_sidebar( array(
        'name'                 => esc_html__( 'Optional Page Sidebar', 'rock-star-pro' ),
        'id'                 => 'sidebar-optional-page',
        'description'        => esc_html__( 'This is Optional Sidebar for Page', 'rock-star-pro' ),
        'before_widget'     => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
        'after_widget'      => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
        'before_title'      => '<h2 class="widget-title">',
        'after_title'       => '</h2>',
    ) );

    //Optional Sidebar for Post instead of main sidebar
    register_sidebar( array(
        'name'                 => esc_html__( 'Optional Post Sidebar', 'rock-star-pro' ),
        'id'                 => 'sidebar-optional-post',
        'description'        => esc_html__( 'This is Optional Sidebar for Post', 'rock-star-pro' ),
        'before_widget'     => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
        'after_widget'      => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
        'before_title'      => '<h2 class="widget-title">',
        'after_title'       => '</h2>',
    ) );

    //Optional Sidebar one for page and post
    register_sidebar( array(
        'name'                 => esc_html__( 'Optional Sidebar One', 'rock-star-pro' ),
        'id'                 => 'sidebar-optional-one',
        'description'        => esc_html__( 'This is Optional Sidebar One', 'rock-star-pro' ),
        'before_widget'     => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
        'after_widget'      => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
        'before_title'      => '<h2 class="widget-title">',
        'after_title'       => '</h2>',
    ) );

    //Optional Sidebar two for page and post
    register_sidebar( array(
        'name'                 => esc_html__( 'Optional Sidebar Two', 'rock-star-pro' ),
        'id'                 => 'sidebar-optional-two',
        'description'        => esc_html__( 'This is Optional Sidebar Two', 'rock-star-pro' ),
        'before_widget'     => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
        'after_widget'      => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
        'before_title'      => '<h2 class="widget-title">',
        'after_title'       => '</h2>',
    ) );

    //Optional Sidebar Three for page and post
    register_sidebar( array(
        'name'                 => esc_html__( 'Optional Sidebar Three', 'rock-star-pro' ),
        'id'                 => 'sidebar-optional-three',
        'description'        => esc_html__( 'This is Optional Sidebar Three', 'rock-star-pro' ),
        'before_widget'     => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
        'after_widget'      => '</div><!-- .widget-wrap --></section><!-- .widget.%2$s -->',
        'before_title'      => '<h2 class="widget-title">',
        'after_title'       => '</h2>',
    ) );

    //Full Page Widget Area
    register_sidebar( array(
        'name'                 => esc_html__( 'Page Template: Blank Page', 'rock-star-pro' ),
        'id'                 => 'blank-page',
        'description'        => esc_html__( 'This is Blank Page Widget Area', 'rock-star-pro' ),
        'before_widget'     => '<section id="%1$s" class="widget page-section %2$s"><div class="widget-wrap wrapper">',
        'after_widget'         => '</div><!-- .widget-wrap --></section>',
        'before_title'         => '<h2 class="widget-title entry-title">',
        'after_title'         => '</h2>'
    ) );

    //Full Page Widget Area With Header and Footer
    register_sidebar( array(
        'name'                 => esc_html__( 'Page Template: Blank Content Page', 'rock-star-pro' ),
        'id'                 => 'blank-content-page',
        'description'        => esc_html__( 'This is Blank Content Page Widget Area with Header and Footer', 'rock-star-pro' ),
        'before_widget'     => '<section id="%1$s" class="widget page-section %2$s"><div class="widget-wrap wrapper">',
        'after_widget'         => '</div><!-- .widget-wrap --></section></section>',
        'before_title'         => '<h2 class="widget-title entry-title">',
        'after_title'         => '</h2>'
    ) );
}
add_action( 'widgets_init', 'rock_star_widgets_init' );

/**
 * Loads up Necessary JS Scripts for widgets
 *
 * @since Rock Star 1.0
 */
function rock_star_widgets_scripts( $hook) {
    if ( 'widgets.php' == $hook ) {
        wp_enqueue_style( 'rock-star-widgets-styles', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'css/widgets.css' );

        wp_enqueue_media();

        wp_enqueue_script( 'rockstar-widgets-scripts', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'js/widget.min.js', array( 'jquery', 'jquery-ui-datepicker' ) );
    }
}
add_action( 'admin_enqueue_scripts', 'rock_star_widgets_scripts' );

// Load About Widget
include get_template_directory() . '/inc/widgets/about.php';

// Load Advertisement Code Widget
include get_template_directory() . '/inc/widgets/advertisement-code.php';

// Load Advertisement Image Widget
include get_template_directory() . '/inc/widgets/advertisement-image.php';

// Load Audio
include get_template_directory() . '/inc/widgets/audio.php';

// Load Background Image Widget
include get_template_directory() . '/inc/widgets/background-image.php';

// Load Breadcrumb Widget
include get_template_directory() . '/inc/widgets/breadcrumb.php';

// Load Featured Embed Widget
include get_template_directory() . '/inc/widgets/featured-embed.php';

// Load Featured Image Widget
include get_template_directory() . '/inc/widgets/featured-image.php';

// Load Featured Page Widget
include get_template_directory() . '/inc/widgets/featured-page.php';

// Load Featured Post Widget
include get_template_directory() . '/inc/widgets/featured-posts.php';

// Load Gallery Image Widget
include get_template_directory() . '/inc/widgets/gallery-image.php';

// Load Gallery Page Widget
include get_template_directory() . '/inc/widgets/gallery-page.php';

// Load Gallery Post Widget
include get_template_directory() . '/inc/widgets/gallery-posts.php';

// Load Instagram Widget
include get_template_directory() . '/inc/widgets/instagram.php';

// Load Newsletter Widget
include get_template_directory() . '/inc/widgets/newsletter.php';

// Load New Ticker Widget
include get_template_directory() . '/inc/widgets/news-ticker.php';

// Load Promotion Headline Widget
include get_template_directory() . '/inc/widgets/promotion-headline.php';

// Load Social Icon Widget
include get_template_directory() . '/inc/widgets/social-icons.php';

// Load Newsletter Widget
include get_template_directory() . '/inc/widgets/tag-cloud.php';

// Load Tours Widget
include get_template_directory() . '/inc/widgets/tours.php';

// Load Featured Post Widget
include get_template_directory() . '/inc/widgets/video-post-page.php';

// Load Video Embed Widget
include get_template_directory() . '/inc/widgets/video-embed.php';